"""
Common types.
"""
from datetime import date
from typing import NewType

Datetime = NewType('Datetime', date)  # TODO add in datetime
